removeLevel_Fn<-function(Matrix)
               {
                for(i in 1:ncol(Matrix))
                     {
                       if(is.factor(Matrix[,i])){Matrix[,i]<-as.character(Matrix[,i])}
                     }
                return(Matrix)
               }
#######################################################################################################
###################################################################################
#####=============           Read Genotype and Phenotype Data      ===========#####
###################################################################################
geno<-read.table("geno.txt",header=T)
pheno<-read.table("phenotype.txt",header=T)
pheno<-as.numeric(unlist(pheno))
###################################################################################
source("MeanVar.r")
source("rAnova.Fn.r")
###################################################################################
#######=======     Select Most Important SNPs using robust ANOVA     =========#####
##########==================       run rANOVA           ====================#######
###################################################################################
pValue<-apply(geno,2,rAnova.Fn)
###################################################################################
#######=======             Omit "NA" values from "pValue"            =========#####
###################################################################################
SNPs<-names(unlist(pValue))
P_Value<-as.vector(unlist(pValue))
###################################################################################
#######=======     Select Most Important SNPs using robust ANOVA     =========#####
###################################################################################
impS<-order(-log10(P_Value),decreasing = T)[1]
s<-geno[,SNPs[impS]] 
pheno.new<-pheno
###################################################################################
#######=======     Detect outlying observarions and replace it      =========#####
###################################################################################
groups <- sort(unique(s))
ngroup <- length(groups)
Xber<-NULL;x1.bar<-NULL;var1<-NULL;# n1pn2<-NULL
  for(i in 1:ngroup)
  {
  b1MeanVar<-MeanVarWt.Beta(pheno[s==groups[i]]) #Robust parameter estimation for each group samples
  OutS0<-b1MeanVar$out 			# Identified outliers
  pheno.new[s==groups[i]][OutS0]<-median(pheno[s==groups[i]])
  }


###################################################################################
#######=======                         Weight Plot                   =========#####
###################################################################################
b1MeanVar<-MeanVarWt.Beta(pheno[s==groups[1]])
b2MeanVar<-MeanVarWt.Beta(pheno[s==groups[2]])
b3MeanVar<-MeanVarWt.Beta(pheno[s==groups[3]])
Weight1<-b1MeanVar$Wt
Weight2<-b2MeanVar$Wt
Weight3<-b3MeanVar$Wt
Y1<-pheno[s==groups[1]]
Y2<-pheno[s==groups[2]]
Y3<-pheno[s==groups[3]]



pdf("newWeightPlot_simulate_wo_outlier.pdf", width=8, height=12.5)
par(mfrow=c(3,2),oma = c(4,3,4,2) ,mai = c(.32,.3,.4,.3))
plot(Y1,type="p")#, xaxt='n', yaxt='n', ann=F,axes=T,lwd=1.2)
#=============================================================================#
#Axis(side=1, at=At, labels=At,padj = -.85,cex.axis=1)
#Axis(side=2, at=c(50,60,70,80,90,100), labels=c(50,60,70,80,90,100),padj = .95,cex.axis=1)
#mtext(side=1,"Index", padj=2.5,cex=1.15)
mtext(side=2,"Phenotypic Observation", padj=-2.3,cex=1.15)

###########################################################################################
plot(Weight1,type="p",ylim=c(0,1))#, xaxt='n', yaxt='n', ann=F,axes=T,lwd=1.2)
abline(h=b1MeanVar$out.Thr,lty=2)
#=============================================================================#
#Axis(side=1, at=At, labels=At,padj = -.85,cex.axis=1)
#Axis(side=2, at=c(50,60,70,80,90,100), labels=c(50,60,70,80,90,100),padj = .95,cex.axis=1)
#mtext(side=1,"Index", padj=2.5,cex=1.15)
mtext(side=2,"Weight", padj=-2.3,cex=1.15)
mtext(side=3,"At genotype level 0", adj=2.7, padj=-1.,cex=1.0)

mtext(side=3,"Genotype Level 0", padj=-1.0, adj=-0.65,cex=1.15)
###########################################################################################
###########################################################################################
plot(Y2,type="p")#, xaxt='n', yaxt='n', ann=F,axes=T,lwd=1.2)
#=============================================================================#
#Axis(side=1, at=At, labels=At,padj = -.85,cex.axis=1)
#Axis(side=2, at=c(50,60,70,80,90,100), labels=c(50,60,70,80,90,100),padj = .95,cex.axis=1)
#mtext(side=1,"Index", padj=2.5,cex=1.15)
mtext(side=2,"Phenotypic Observation", padj=-2.3,cex=1.15)
###########################################################################################
plot(Weight2,type="p",ylim=c(0,1))#, xaxt='n', yaxt='n', ann=F,axes=T,lwd=1.2)
abline(h=b2MeanVar$out.Thr,lty=2)
#=============================================================================#
#Axis(side=1, at=At, labels=At,padj = -.85,cex.axis=1)
#Axis(side=2, at=c(50,60,70,80,90,100), labels=c(50,60,70,80,90,100),padj = .95,cex.axis=1)
#mtext(side=1,"Index", padj=2.5,cex=1.15)
mtext(side=2,"Weight", padj=-2.3,cex=1.15)
mtext(side=3,"At genotype level 2", adj=2.7, padj=-1.,cex=1.0)

mtext(side=3,"Genotype Level 1", padj=-1.0, adj=-0.65,cex=1.15)
###########################################################################################
###########################################################################################
plot(Y3,type="p")#, xaxt='n', yaxt='n', ann=F,axes=T,lwd=1.2)
#=============================================================================#
#Axis(side=1, at=At, labels=At,padj = -.85,cex.axis=1)
#Axis(side=2, at=c(50,60,70,80,90,100), labels=c(50,60,70,80,90,100),padj = .95,cex.axis=1)
mtext(side=1,"Index", padj=2.5,cex=1.15)
mtext(side=2,"Phenotypic Observation", padj=-2.3,cex=1.15)
###########################################################################################
plot(Weight3,type="p",ylim=c(0,1))#, xaxt='n', yaxt='n', ann=F,axes=T,lwd=1.2)
abline(h=b3MeanVar$out.Thr,lty=2)
#=============================================================================#
#Axis(side=1, at=At, labels=At,padj = -.85,cex.axis=1)
#Axis(side=2, at=c(50,60,70,80,90,100), labels=c(50,60,70,80,90,100),padj = .95,cex.axis=1)
mtext(side=1,"Index", padj=2.5,cex=1.15)
mtext(side=2,"Weight", padj=-2.3,cex=1.15)
mtext(side=3,"At genotype level 2", adj=2.7, padj=-1.,cex=1.0)

mtext(side=3,"Genotype Level 2", padj=-1.0, adj=-0.65,cex=1.15)
dev.off()



###################################################################################
#######=======      Calculate Kinship Matrix implemented in EMMA      ========#####
###################################################################################
source("KinshipEmma.r")
K<-KinshipEmma(geno)
###################################################################################
#######=======  Perform GWAS using mixed model implemented in EMMA    ========#####
###################################################################################
source("emma.r")
EmmaResult_Prop1<- emma.REML.t(ys=pheno.new,xs=t(geno),K=K)#,X0=cbind(1,COV)
P1<-EmmaResult_Prop1$ps
rownames(P1)<-SNPs
P1[P1<.000001,]

###################################################################################
#######=======                       Manhattan Plot                  =========#####
###################################################################################
sigID<-names(P1[P1<0.99999,])
sigP<-as.vector(P1[P1<0.99999,])

MAP<-read.table("Map.map")
MAP<-removeLevel_Fn(MAP)
ID<-MAP$V2
Pos<-MAP$V4
Chr<-MAP$V1
sigPos<-Pos[ID%in%sigID]
sigChr<-Chr[ID%in%sigID]


sigSNP.info<-data.frame(
                        chr=sigChr,
                        SNPID=sigID,
                        pos=sigPos,
                        pvalue=sigP
                       )




source("manhattan.plot.Fn.r")
manhattan.plot(sigSNP.info$chr, Pos, sigSNP.info$pvalue, sig.level=1.35e-5, should.thin=T,col=c("red","green","blue","forestgreen","darkmagenta","gray25"))











